emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

feature/package+vc 8e6e6e6de5 2/2: Rename 'package-vc-fetch' to 'package


From: Philip Kaludercic
Subject: feature/package+vc 8e6e6e6de5 2/2: Rename 'package-vc-fetch' to 'package-vc-install'
Date: Sun, 9 Oct 2022 17:37:41 -0400 (EDT)

branch: feature/package+vc
commit 8e6e6e6de511ea5cf664a17761e879077aa07e0d
Author: Philip Kaludercic <philipk@posteo.net>
Commit: Philip Kaludercic <philipk@posteo.net>

    Rename 'package-vc-fetch' to 'package-vc-install'
    
    * lisp/emacs-lisp/package-vc.el (package-vc-fetch): Rename to preserve
    symmetry with 'package-install'.
    (package-checkout): Follow the previous rename.
---
 lisp/emacs-lisp/package-vc.el | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lisp/emacs-lisp/package-vc.el b/lisp/emacs-lisp/package-vc.el
index e02213ed3f..f5cf90963f 100644
--- a/lisp/emacs-lisp/package-vc.el
+++ b/lisp/emacs-lisp/package-vc.el
@@ -30,7 +30,7 @@
 ;;   * Detect merge conflicts                                   TODO
 ;;   * Check if there are upstream changes                      TODO
 ;; - Allow finding revisions that bump the version tag          TODO
 ;;   * Allow for `package-vc-fetch' to use the version
 ;;     of the package if already installed.
 ;; - Allow for ELPA specifications to be respected without      TODO
 ;;   endangering the user with arbitrary code execution
@@ -276,7 +276,7 @@ The output is written out into PKG-FILE."
       (vc-pull))))
 
 ;;;###autoload
-(defun package-vc-fetch (name-or-url &optional name rev)
+(defun package-vc-install (name-or-url &optional name rev)
   "Fetch the source of NAME-OR-URL.
 If NAME-OR-URL is a URL, then the package will be downloaded from
 the repository indicated by the URL.  The function will try to
@@ -319,7 +319,7 @@ be requested using REV."
     ((user-error "Unknown package to fetch: %s" name-or-url)))))
 
 ;;;###autoload
-(defalias 'package-checkout #'package-vc-fetch)
+(defalias 'package-checkout #'package-vc-install)
 
 (defun package-vc-read-pkg (prompt)
   "Query for a source package description with PROMPT."
@@ -30,7 +30,7 @@
 ;;   * Check if there are upstream changes                      TODO
 ;; - Allow finding revisions that bump the version tag          TODO
-;;   * Allow for `package-vc-fetch' to use the version
+;;   * Allow for `package-vc-install' to use the version
 ;;     of the package if already installed.
 ;; - Allow for ELPA specifications to be respected without      TODO



reply via email to

[Prev in Thread] Current Thread [Next in Thread]